@@ -17,13 +17,12 @@ function spy(cb) {
       }
     } else {
       let result
-      if (cb) result = cb(...args)
+      if (fn.impl) result = fn.impl(...args)
       fn.results.push(result)
       return result
     }
   }
 
-  Object.defineProperty(fn, 'length', { value: cb ? cb.length : 0 })
   fn.called = false
   fn.callCount = 0
   fn.results = []
@@ -34,6 +33,37 @@ function spy(cb) {
   fn.nextResult = result => {
     fn.next = ['ok', result]
   }
+  fn.nextResolve = () => {
+    let promiseResolve
+    let promise = new Promise(resolve => {
+      promiseResolve = resolve
+    })
+    fn.next = ['ok', promise]
+    return result => {
+      promiseResolve(result)
+      return new Promise(resolve => {
+        setTimeout(resolve, 10)
+      })
+    }
+  }
+  fn.nextReject = () => {
+    let promiseReject
+    let promise = new Promise((resolve, reject) => {
+      promiseReject = reject
+    })
+    fn.next = ['ok', promise]
+    return error => {
+      promiseReject(error)
+      return new Promise(resolve => {
+        setTimeout(resolve, 10)
+      })
+    }
+  }
+  fn.onCall = body => {
+    Object.defineProperty(fn, 'length', { value: body ? body.length : 0 })
+    fn.impl = body
+  }
+  fn.onCall(cb)
 
   return fn
 }
